==> speechanalytic-billing_0.1.4_database.tar.gz: database/mssql/procedures/ActivatePlatform.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[ActivatePlatform]
(
	@PlatformHash			VARCHAR(100),
	@InstallationId			VARCHAR(50),
	@MacAddress				VARCHAR(50),
	@PublicIp				VARCHAR(50),
	@User					VARCHAR(50),
	@Token					VARCHAR(50)
)
AS
BEGIN
	SET XACT_ABORT, NOCOUNT ON;

	-- ABRIMOS EL TRY PARA LA TRANSACCION
    BEGIN TRY
        BEGIN TRANSACTION

		-- DECLARAMOS UNA VARIABLE PARA ALMACENAR UN FLAG SI EXISTE EL PLATFORM HASH
		DECLARE @PLATFORMHASH_EXISTS BIT

		-- DECLARAMOS UNA VARIABLE PARA ALMACENAR UN FLAG SI EXISTE LA CUENTA PRINCIPAL O CUENTA DE ACTIVACION
		DECLARE @MAINACCOUNT VARCHAR(50)

		-- SETTEAMOS UN VALOR FALSE POR DEFECTO
		SET @PLATFORMHASH_EXISTS = 0

		-- SETTEAMOS UN VALOR FALSE POR DEFECTO
		SET @MAINACCOUNT = NULL

		-- VALIDAMOS SI YA EXISTE UNA PLATAFORMA CON EL INSTALLATION ID
		/*
			IF EXISTS (
				SELECT P.[InstallationId]
					FROM [dbo].[Platform] P (NOLOCK)
					WHERE P.[InstallationId] = @InstallationId 
			)
				-- LANZAMOS MESAJE AVISANDO QUE NO SE ENCONTRO LA CUENTA
				RAISERROR('DATABABASE_ERROR_INSTALLATION_ID_REPEAT', 16, 16)*/

		-- VALIDAMOS QUE EL PLATFORMHASH ESTA REGISTRADO EN LA TABLA PLATFORM
		SELECT TOP 1 @PLATFORMHASH_EXISTS = CASE WHEN P.[PlatformHash] IS NOT NULL THEN 1 END
			FROM dbo.[Platform] P (NOLOCK) 
			WHERE P.[PlatformHash] = @PlatformHash 

		-- VALIDAMOS QUE EL USUARIO, TOKEN E INSTALLATIONID COINCIDEN CON LOS DE LA TABLA ACCOUNT
		SELECT TOP 1 @MAINACCOUNT = A.[AccountId] 
			FROM dbo.[Account] A (NOLOCK)
			WHERE A.[PlatformHash] = @PlatformHash 
				AND A.[User] = @User
				AND A.[Token] = @Token
				AND A.[AccountLevel] = 1 
				AND A.[InstallationId] IS NULL
				AND A.[SubAccountId] IS NULL

		-- VERIFICAMOS QUE AMBOS RESULTADOS EXISTAN
		IF @PLATFORMHASH_EXISTS = 1 AND @MAINACCOUNT IS NOT NULL
		BEGIN
		
			-- ACTUALIZAMOS LA PLATAFORMA CON SUS DATOS DE INFRAESTRUCTURA
			UPDATE [dbo].[Platform] 
				SET [InstallationId] = @InstallationId,
					[MacAddress] = @MacAddress,
					[PublicIp] = @PublicIp,
					[IsActivated] = 1,
					[ActivationDate] = GETUTCDATE(),
					[LastModifiedDate] = GETUTCDATE(),
					[LastModifiedByUserId] = @User,
					[TimeStamp] = GETUTCDATE()
				WHERE
					[PlatformHash] = @PlatformHash

			IF (@@ROWCOUNT = 0) 
				RAISERROR('DATABASE_ERROR_PLATFORM_UPDATE_FAILED', 16, 16)
				

			-- ACTUALIZAMOS LA COLUMNA INSTALLATIONID EN LA TABLA PLATFORMDATA
			UPDATE dbo.[PlatformData] 
				SET [InstallationId] = @InstallationId,
					[LastModifiedDate] = GETUTCDATE(),
					[LastModifiedByUserId] = @User,
					[TimeStamp] = GETUTCDATE()
				WHERE [PlatformHash] = @PlatformHash

			IF (@@ROWCOUNT = 0) 
				RAISERROR('DATABASE_ERROR_PLATFORMDATA_UPDATE_FAILED', 16, 16)

			-- ACTUALIZAMOS LA COLUMNA INSTALLATIONID EN LA TABLA ACCOUNT PARA LA MAIN ACCOUNT
			UPDATE dbo.[Account] 
				SET [InstallationId] = @InstallationId,
					[LastModifiedDate] = GETUTCDATE(),
					[LastModifiedByUserId] = @User,
					[TimeStamp] = GETUTCDATE()
				WHERE [PlatformHash] = @PlatformHash
					AND [User] = @User
					AND [Token] = @Token
					AND [AccountLevel] = 1
		
			IF (@@ROWCOUNT = 0) 
				RAISERROR('DATABASE_ERROR_ACCOUNT_UPDATE_FAILED', 16, 16)


			-- ACTUALIZAMOS LA COLUMNA INSTALLATIONID EN LA TABLA ACCOUNTBALANCE PARA LA MAIN ACCOUNT
			UPDATE dbo.[AccountBalance] 
				SET [InstallationId] = @InstallationId,
					[LastModifiedDate] = GETUTCDATE(),
					[LastModifiedByUserId] = @User,
					[TimeStamp] = GETUTCDATE()
				WHERE [PlatformHash] = @PlatformHash 
					AND [AccountId] = @MAINACCOUNT

			IF (@@ROWCOUNT = 0) 
				RAISERROR('DATABASE_ERROR_ACCOUNTBALANCE_UPDATE_FAILED', 16, 16)

			-- ACTUALIZAMOS LA COLUMNA INSTALLATIONID EN LA TABLA DE MOVIMIENTOS
			UPDATE [dbo].[AccountSubAccountVCCBalanceMovement]
				SET [InstallationId] = @InstallationId
				WHERE [InstallationId]  IS NULL
					AND [AccountId] = @MAINACCOUNT
					AND [SubAccountId] IS NULL
					
			IF (@@ROWCOUNT = 0) 
				RAISERROR('DATABASE_ERROR_ACCOUNTSUBACCOUNTVCCBALANCEMOVEMENT_UPDATE_FAILED', 16, 16)

			-- ACTUALIZAMOS LA COLUMNA INSTALLATIONID EN LA TABLA PLATFORMLICENSE
			UPDATE dbo.[PlatformLicense] 
				SET [InstallationId] = @InstallationId,
					[LastModifiedDate] = GETUTCDATE(),
					[LastModifiedByUserId] = @User,
					[TimeStamp] = GETUTCDATE()
				WHERE [PlatformHash] = @PlatformHash 

			IF (@@ROWCOUNT = 0) 
				RAISERROR('DATABASE_ERROR_PLATFORMLICENSE_UPDATE_FAILED', 16, 16)

			-- SELECT 1 AS 'result'
			SELECT P.[InstallationId] 'installationId', 
					P.[MacAddress] 'macAddress', 
					P.[BaseBoardSerialNumber] 'baseBoardSerialNumber',
					P.[PublicIp] 'publicIp',
					P.[IsActivated] 'isActivated'
				FROM [dbo].[Platform] P
				WHERE P.[PlatformHash] = @PlatformHash 

		END
		ELSE
		BEGIN 
			CREATE TABLE #DUMMY ( A Int, B VarChar(42) )
			SELECT * FROM #DUMMY
		END

	-- CONSOLIDAMOS LA TRANSACCION
		COMMIT TRANSACTION

    -- TERMINAMOS EL TRY PARA LA TRANSACCION
    END TRY
	BEGIN CATCH
        IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH

   SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speechanalytic-billing_1.0.1_database.tar.gz: database/mssql/procedures/ActivatePlatform.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[ActivatePlatform]
(
	@PlatformHash			VARCHAR(100),
	@InstallationId			VARCHAR(50),
	@MacAddress				VARCHAR(50),
	@PublicIp				VARCHAR(50),
	@User					VARCHAR(50),
	@Token					VARCHAR(50)
)
AS
BEGIN
	SET XACT_ABORT, NOCOUNT ON;

	-- ABRIMOS EL TRY PARA LA TRANSACCION
    BEGIN TRY
        BEGIN TRANSACTION

		-- DECLARAMOS UNA VARIABLE PARA ALMACENAR UN FLAG SI EXISTE EL PLATFORM HASH
		DECLARE @PLATFORMHASH_EXISTS BIT

		-- DECLARAMOS UNA VARIABLE PARA ALMACENAR UN FLAG SI EXISTE LA CUENTA PRINCIPAL O CUENTA DE ACTIVACION
		DECLARE @MAINACCOUNT VARCHAR(50)

		-- SETTEAMOS UN VALOR FALSE POR DEFECTO
		SET @PLATFORMHASH_EXISTS = 0

		-- SETTEAMOS UN VALOR FALSE POR DEFECTO
		SET @MAINACCOUNT = NULL

		-- VALIDAMOS SI YA EXISTE UNA PLATAFORMA CON EL INSTALLATION ID
		/*
			IF EXISTS (
				SELECT P.[InstallationId]
					FROM [dbo].[Platform] P (NOLOCK)
					WHERE P.[InstallationId] = @InstallationId 
			)
				-- LANZAMOS MESAJE AVISANDO QUE NO SE ENCONTRO LA CUENTA
				RAISERROR('DATABABASE_ERROR_INSTALLATION_ID_REPEAT', 16, 16)*/

		-- VALIDAMOS QUE EL PLATFORMHASH ESTA REGISTRADO EN LA TABLA PLATFORM
		SELECT TOP 1 @PLATFORMHASH_EXISTS = CASE WHEN P.[PlatformHash] IS NOT NULL THEN 1 END
			FROM dbo.[Platform] P (NOLOCK) 
			WHERE P.[PlatformHash] = @PlatformHash 

		-- VALIDAMOS QUE EL USUARIO, TOKEN E INSTALLATIONID COINCIDEN CON LOS DE LA TABLA ACCOUNT
		SELECT TOP 1 @MAINACCOUNT = A.[AccountId] 
			FROM dbo.[Account] A (NOLOCK)
			WHERE A.[PlatformHash] = @PlatformHash 
				AND A.[User] = @User
				AND A.[Token] = @Token
				AND A.[AccountLevel] = 1 
				AND (
					A.[InstallationId] IS NULL 
					OR 
					(A.[InstallationId] IS NOT NULL AND A.[InstallationId] = @InstallationId)
				)
				AND A.[SubAccountId] IS NULL

		-- VERIFICAMOS QUE AMBOS RESULTADOS EXISTAN
		IF @PLATFORMHASH_EXISTS = 1 AND @MAINACCOUNT IS NOT NULL
		BEGIN
		
			-- ACTUALIZAMOS LA PLATAFORMA CON SUS DATOS DE INFRAESTRUCTURA
			UPDATE [dbo].[Platform] 
				SET [InstallationId] = @InstallationId,
					[MacAddress] = @MacAddress,
					[PublicIp] = @PublicIp,
					[IsActivated] = 1,
					[ActivationDate] = GETUTCDATE(),
					[LastModifiedDate] = GETUTCDATE(),
					[LastModifiedByUserId] = @User,
					[TimeStamp] = GETUTCDATE()
				WHERE
					[PlatformHash] = @PlatformHash

			IF (@@ROWCOUNT = 0) 
				RAISERROR('DATABASE_ERROR_PLATFORM_UPDATE_FAILED', 16, 16)
				

			-- ACTUALIZAMOS LA COLUMNA INSTALLATIONID EN LA TABLA PLATFORMDATA
			UPDATE dbo.[PlatformData] 
				SET [InstallationId] = @InstallationId,
					[LastModifiedDate] = GETUTCDATE(),
					[LastModifiedByUserId] = @User,
					[TimeStamp] = GETUTCDATE()
				WHERE [PlatformHash] = @PlatformHash

			IF (@@ROWCOUNT = 0) 
				RAISERROR('DATABASE_ERROR_PLATFORMDATA_UPDATE_FAILED', 16, 16)

			-- ACTUALIZAMOS LA COLUMNA INSTALLATIONID EN LA TABLA ACCOUNT PARA LA MAIN ACCOUNT
			UPDATE dbo.[Account] 
				SET [InstallationId] = @InstallationId,
					[LastModifiedDate] = GETUTCDATE(),
					[LastModifiedByUserId] = @User,
					[TimeStamp] = GETUTCDATE()
				WHERE [PlatformHash] = @PlatformHash
					AND [User] = @User
					AND [Token] = @Token
					AND [AccountLevel] = 1
		
			IF (@@ROWCOUNT = 0) 
				RAISERROR('DATABASE_ERROR_ACCOUNT_UPDATE_FAILED', 16, 16)


			-- ACTUALIZAMOS LA COLUMNA INSTALLATIONID EN LA TABLA ACCOUNTBALANCE PARA LA MAIN ACCOUNT
			UPDATE dbo.[AccountBalance] 
				SET [InstallationId] = @InstallationId,
					[LastModifiedDate] = GETUTCDATE(),
					[LastModifiedByUserId] = @User,
					[TimeStamp] = GETUTCDATE()
				WHERE [PlatformHash] = @PlatformHash 
					AND [AccountId] = @MAINACCOUNT

			IF (@@ROWCOUNT = 0) 
				RAISERROR('DATABASE_ERROR_ACCOUNTBALANCE_UPDATE_FAILED', 16, 16)

			-- ACTUALIZAMOS LA COLUMNA INSTALLATIONID EN LA TABLA DE MOVIMIENTOS
			UPDATE [dbo].[AccountSubAccountVCCBalanceMovement]
				SET [InstallationId] = @InstallationId
				WHERE (
						[InstallationId] IS NULL 
						OR 
						([InstallationId] IS NOT NULL AND [InstallationId] = @InstallationId)
					)
					AND [AccountId] = @MAINACCOUNT
					AND [SubAccountId] IS NULL
					
			IF (@@ROWCOUNT = 0) 
				RAISERROR('DATABASE_ERROR_ACCOUNTSUBACCOUNTVCCBALANCEMOVEMENT_UPDATE_FAILED', 16, 16)

			-- ACTUALIZAMOS LA COLUMNA INSTALLATIONID EN LA TABLA PLATFORMLICENSE
			UPDATE dbo.[PlatformLicense] 
				SET [InstallationId] = @InstallationId,
					[LastModifiedDate] = GETUTCDATE(),
					[LastModifiedByUserId] = @User,
					[TimeStamp] = GETUTCDATE()
				WHERE [PlatformHash] = @PlatformHash 

			IF (@@ROWCOUNT = 0) 
				RAISERROR('DATABASE_ERROR_PLATFORMLICENSE_UPDATE_FAILED', 16, 16)

			-- SELECT 1 AS 'result'
			SELECT P.[InstallationId] 'installationId', 
					P.[MacAddress] 'macAddress', 
					P.[BaseBoardSerialNumber] 'baseBoardSerialNumber',
					P.[PublicIp] 'publicIp',
					P.[IsActivated] 'isActivated'
				FROM [dbo].[Platform] P
				WHERE P.[PlatformHash] = @PlatformHash 

		END
		ELSE
		BEGIN 
			CREATE TABLE #DUMMY ( A Int, B VarChar(42) )
			SELECT * FROM #DUMMY
		END

	-- CONSOLIDAMOS LA TRANSACCION
		COMMIT TRANSACTION

    -- TERMINAMOS EL TRY PARA LA TRANSACCION
    END TRY
	BEGIN CATCH
        IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH

   SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
